import { useCallback, useEffect, useState } from 'react';
import { useAsyncProcess } from '@onomy/react-utils';
import { useOnexClient } from '../hooks';

export function useCancelOrderForm({ orderId = '' } = {}) {
  const onex = useOnexClient();
  const [attemptTx, txStatus, resetTxStatus] = useAsyncProcess();
  const [txResult, setTxResult] = useState<null | Awaited<ReturnType<typeof onex.cancelOrder>>>(
    null
  );

  const [uid, setUid] = useState(orderId);

  const doCancel = useCallback(
    (id: string) => {
      resetTxStatus();
      setTxResult(null);
      return attemptTx(async () => setTxResult(await onex.cancelOrder({ uid: id })));
    },
    [onex, resetTxStatus, attemptTx]
  );

  const submitTx = useCallback(
    (e?: React.FormEvent) => {
      e?.preventDefault();
      return doCancel(uid);
    },
    [doCancel, uid]
  );

  const reset = useCallback(() => {
    resetTxStatus();
    setTxResult(null);
  }, [resetTxStatus]);

  useEffect(() => {
    setUid(orderId);
    reset();
  }, [orderId, reset]);

  return {
    txStatus,
    txResult,

    doCancel,
    submitTx,
    reset,
  };
}
